/*                SPLIT PLOT REPEATED MEASURES                */

/*Requires the macros
F1_LD_F2
LD_CI
*/

/*Specify the pathways to the macros for your computer*/
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\LD_CI.sas';
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\F1_LD_F2.sas';

/*Data courtesy of Reza Darvish, INP-ENSAT France

race = Phoma race, whole plot factor
gtype = sunflower genotype, the sub plot factor
rep = replication
bss3 = median black stem severity 3 days post-inoculation
bss5 = median black stem severity 5 days post-inoculation
bss7 = median black stem severity 7 days post-inoculation
time = days after inoculation

The design is a split-plot with repeated neasurements,
which can be analyzed as a split-split plot with time as a sub plot factor.*/
options ls =100 ps= 1000 nodate nonumber;
data phoma;
input race $  gtype rep bss3 bss5 bss7;
cards;
A	32	1	0	0	3.5
A	32	2	0	2	3.5
A	32	3	1	3.5	7
A	34	1	0	1	1.5
A	34	2	0.5	0.5	2
A	34	3	0.5	1	2
A	35	1	1	2	2
A	35	2	1	1	1.5
A	35	3	1.5	2	2
B	32	1	3	4	9
B	32	2	6	8	9
B	32	3	4	5	7
B	34	1	3	3.5	6
B	34	2	1	1	4
B	34	3	3	4	6.5
B	35	1	1	1.5	2
B	35	2	1.5	1.5	2
B	35	3	2	2	4.5
C	32	1	0.5	1	1.5
C	32	2	0	0	1
C	32	3	0.5	1	1.5
C	34	1	1	1	1
C	34	2	1	1	1
C	34	3	0.5	1	1
C	35	1	1	2.5	3
C	35	2	3.5	5.5	6
C	35	3	2	3.5	4
D	32	1	1	1.5	1.5
D	32	2	1	1	2.5
D	32	3	1	1.5	3
D	34	1	1	1	2
D	34	2	1	1	1
D	34	3	1	1	1.5
D	35	1	1	1	3
D	35	2	0	0.5	1
D	35	3	0.5	1	2
;
run;

/*Check the dataset*/
title 'ORIGINAL DATA';
%macro skip;
proc print data=phoma;
run;
%mend skip;


/*First, get the data in univariate format for analysis by macros and Proc Mixed*/
data phoma2;
 set phoma;
 t1=bss3;
 t2=bss5;
 t3=bss7;
  array t{3} t1-t3;
  do i=1 to 3;
    if i=1 then time=3;
	if i=2 then time=5;
	if i=3 then time=7;
    bss=t{i};
	output;
  end;
  drop i t1-t3 bss3 bss5 bss7;
run;

/*Create a character variable for subject.
Each subject is the unique combination of rep and race*/
data phoma2; set phoma2;
	sub2 = "rep"||put(rep,1.)||"_"||race; *<--MAKE CORRECT SUBJECT VARIABLE BY CONCATENATING REPC AND RACE;
/*Create a variable for the different combinations of gtype and time*/
	gtype_time = "gtype="||put(gtype,2.)||"_"||"time="||left(put(time,2.)); 
run;

/*Take a look at the data in univariate format*/
title 'DATA IN UNIVARIATE FORMAT';
proc print data=phoma2;
run;

/*Summary of the median ratings*/
title 'MEDIAN RATINGS SUMMARY';
proc tabulate data=phoma2 f=6.1;
  class race gtype time;
  var bss;
  table race*gtype, time*bss*(median); *<--Request median rating;
run;


/*Nonparametric analysis using the F1_LD_F2 macro*/
title1'NONPARAMETRIC ANALYSIS WITH THE F1_LD_F2 MACRO';
%F1_LD_F2(data=phoma2, var=bss, factor=race, time1=gtype, time2=time, subject=sub2);
/*Get the relative treatment effects and confidence intervals*/
title 'RELATIVE TREATMENT EFFECTS';
%LD_CI(data=phoma2, var=bss, group=race, time=gtype_time, subject=sub2);
run;


/*           NONPARAMETRIC ANALYSIS USING PROC MIXED        */
title 'ANALYSIS USING PROC MIXED';
/*First, obtain the ranks*/
proc rank data=phoma2 out=phoma2;
	var bss;
    ranks r;
run;
/*Sort by whole-plot factor, then subject, then sub-plot factors*/
proc sort data=phoma2 out=phoma2;
  by race sub2 gtype time;
run;
proc mixed data=phoma2 anovaf method=mivque0;
class race sub2 gtype time;
model r = race|gtype|time / chisq;
repeated gtype*time /type=un grp=race sub=sub2;
* lsmeans race*time;
lsmeans race*gtype;
ods output lsmeans=c; *<--Output the lsmeans to dataset c;
run;



/*                 PLOTTING RELATIVE TREATMENT EFFECTS                */
/*One may want to visualize the relative treatment effects.
  Here we calculate the relative treatment effects from the lsmeans.*/
data c2;
  set c;
  re = (Estimate-0.5)/108; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENT EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc tabulate data=c2 f=8.2;
  * class race time;
  class race gtype;
  var re;
  * table race, time*re*(mean);
  table race, gtype*re*(mean); *<--For race*gtype re;
run;

/*Now plot re*/
goptions reset=all;
symbol1 v=dot i=join;
title 'PLOT OF RELATIVE TREATMENT EFFECTS';
proc gplot data = c2;
  * plot re*time = race;
  plot re*gtype = race;
run;
quit;




