/*               SPLIT SPLIT PLOT EXAMPLE      */

/*Requires the macros
F1_LD_F2
LD_CI
*/

/*Specify the pathways to the macros for your computer*/
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\LD_CI.sas';
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\F1_LD_F2.sas';

/*Data courtesy of Julie Schimelfenig, University of Nebraska*/


/*rep = rep (or block)*/
/*irr = irrigation treatment: WHOLE PLOT TRT*/
/*herb = herbicide treatment: SUB PLOT TRT*/
/*fert = fertilizer treatment: SUB-SUB PLOT TRT*/
/*rating = rating done on plot*/
/*subject = subject code.  Each irr by rep combination is a unique
  subject*/
options ls =100 ps= 1000 nodate nonumber;
data ssp;
input rep irr herb fert rating;
sub = "irr="||put(irr,1.)||"_"||"rep="||put(rep,1.); *<--A descriptive subject label;
/*Create a variable for the different combinations of herb and fert*/
herb_fert = "herb="||put(herb,1.)||"_"||"fert="||left(put(fert,1.)); 
cards;
1	1	1	1	1.8
1	1	1	2	2.5
1	1	2	1	3.5
1	1	2	2	4.7
1	2	1	1	2.1
1	2	1	2	3.5
1	2	2	1	4.3
1	2	2	2	4.9
2	1	1	1	1.9
2	1	1	2	2.9
2	1	2	1	4.4
2	1	2	2	5.6
2	2	1	1	2.1
2	2	1	2	4.1
2	2	2	1	4.9
2	2	2	2	5.2
3	1	1	1	2.7
3	1	1	2	3.3
3	1	2	1	4.4
3	1	2	2	6.1
3	2	1	1	1.2
3	2	1	2	1.7
3	2	2	1	4.6
3	2	2	2	7.7
;
run;

/*Check the dataset*/
title 'ORIGINAL DATA';
proc print data=ssp;
run;

/*Summary of the median ratings*/
title 'MEDIAN RATINGS SUMMARY';
proc tabulate data=ssp f=6.1;
  class irr herb fert;
  var rating;
  table irr*herb, fert*rating*(median); *<--Request median rating;
run;


/*Nonparametric analysis using the F1_LD_F2 macro*/
title1'NONPARAMETRIC ANALYSIS WITH THE F1_LD_F2 MACRO';
%F1_LD_F2(data=ssp, var=rating, factor=irr, time1=herb, time2=fert, subject=sub);
/*Get the relative treatment effects and confidence intervals*/
title 'RELATIVE TREATMENT EFFECTS';
%LD_CI(data=ssp, var=rating, group=irr, time=herb_fert, subject=sub);
run;


/*           NONPARAMETRIC ANALYSIS USING PROC MIXED        */
title 'ANALYSIS USING PROC MIXED';
/*First, obtain the ranks*/
proc rank data=ssp out=ssp;
	var rating;
    ranks r;
run;
/*Sort by whole-plot factor, then subject, then sub-plot factors*/
proc sort data=ssp out=ssp;
  by irr sub herb fert;
run;
proc mixed data=ssp anovaf method=mivque0;
class irr sub herb fert;
model r = irr|herb|fert / chisq;
repeated herb*fert /type=un grp=irr sub=sub;
* lsmeans irr*fert;
lsmeans irr*herb;
ods output lsmeans=c; *<--Output the lsmeans to dataset c;
run;



/*                 PLOTTING RELATIVE TREATMENT EFFECTS                */
/*One may want to visualize the relative treatment effects.
  Here we calculate the relative treatment effects from the lsmeans.*/
data c2;
  set c;
  re = (Estimate-0.5)/24; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENT EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc print data=c2;
run;
proc tabulate data=c2 f=8.2;
  * class irr fert;
  class irr herb;
  var re;
  * table irr, fert*re*(mean);
  table irr, herb*re*(mean); *<--For irr*herb re;
run;

/*Now plot re*/
goptions reset=all;
symbol1 v=dot i=join;
title 'PLOT OF RELATIVE TREATMENT EFFECTS';
proc gplot data = c2;
  * plot re*fert = irr;
  plot re*herb = irr;
run;
quit;




