/*               TWO-WAY FACTORIAL                     */

/*Requires the following macro:
LD_CI
*/
/*Set the pathway to the macro for your computer*/
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\LD_CI.sas';

/*Data courtesy of Camilla Yandoc, USDA ARS USHRL*/
options ls =100 ps= 1000 nodate nonumber;
/*Two way factorial example*/
/*5 different biocontrol agents (trt) and 3 different fertilizer levels (fert)
are tested for their effects on stem rot of vinca caused by
Phytophthora nicotianae*/

/*
trt = NT A B C D E  NT=untreated control
fert = fertilizer level (1 2 3) 1=no fertilizer, 2=0.5x, 3=1.0x
rep = replication (1 2 3 4 5)
dsr = disease rating 0-4 scale 21 days after treatments applied
group = unique identifier for each trt x fert combination
*/

/*original dataset*/
data vinca;
input subject trt $ fert rep dsr21 group;
group2 = right(trt)||"_"||"fert="||put(fert,1.); *<--A more descriptive variable for group;
cards;
1      NT        1      1       4         1
2      NT        1      2       4         1
3      NT        1      3       4         1
4      NT        1      4       2         1
5      NT        1      5       4         1
6      NT        2      1       4         2
7      NT        2      2       1         2
8      NT        2      3       0         2
9      NT        2      4       4         2
10      NT        2      5       4         2
11      NT        3      1       4         3
12      NT        3      2       2         3
13      NT        3      3       4         3
14      NT        3      4       4         3
15      NT        3      5       4         3
21      D      1      1       0         5
22      D      1      2       0         5
23      D      1      3       0         5
24      D      1      4       0         5
25      D      1      5       0         5
26      D      2      1       0         6
27      D      2      2       0         6
28      D      2      3       0         6
29      D      2      4       0         6
30      D      2      5       0         6
31      D      3      1       0         7
32      D      3      2       0         7
33      D      3      3       0         7
34      D      3      4       0         7
35      D      3      5       0         7
41      E      1      1       0         9
42      E      1      2       0         9
43      E      1      3       0         9
44      E      1      4       0         9
45      E      1      5       0         9
46      E      2      1       0        10
47      E      2      2       0        10
48      E      2      3       0        10
49      E      2      4       0        10
50      E      2      5       0        10
51      E      3      1       0        11
52      E      3      2       0        11
53      E      3      3       0        11
54      E      3      4       0        11
55      E      3      5       0        11
61      A        1      1       0        13
62      A        1      2       4        13
63      A        1      3       0        13
64      A        1      4       0        13
65      A        1      5       0        13
66      A        2      1       0        14
67      A        2      2       4        14
68      A        2      3       4        14
69      A        2      4       3        14
70      A        2      5       4        14
71      A        3      1       0        15
72      A        3      2       4        15
73      A        3      3       1        15
74      A        3      4       3        15
75      A        3      5       4        15
141      B        1      1       0        29
142      B        1      2       4        29
143      B        1      3       0        29
144      B        1      4       1        29
145      B        1      5       3        29
146      B        2      1       2        30
147      B        2      2       2        30
148      B        2      3       0        30
149      B        2      4       0        30
150      B        2      5       4        30
151      B        3      1       0        31
152      B        3      2       0        31
153      B        3      3       4        31
154      B        3      4       4        31
155      B        3      5       3        31
181      C        1      1       4        37
182      C        1      2       0        37
183      C        1      3       0        37
184      C        1      4       0        37
185      C        1      5       4        37
186      C        2      1       4        38
187      C        2      2       4        38
188      C        2      3       4        38
189      C        2      4       4        38
190      C        2      5       2        38
191      C        3      1       4        39
192      C        3      2       4        39
193      C        3      3       1        39
194      C        3      4       4        39
195      C        3      5       3        39
;
run;

/*Check the data*/
title 'THE RAW DATA';
proc print data=vinca noobs;
run;

/*Summary of the median ratings*/
title 'MEDIAN RATINGS SUMMARY';
proc tabulate data=vinca f=6.2;
  class trt fert;
  var dsr21;
  table trt, fert*dsr21*(median n); *<--Request median rating;
run;


/*         NONPARAMETRIC ANALYSIS USING PROC MIXED         */
/*Obtain the ranks*/
proc rank data=vinca out=vinca;
  var dsr21; 
  ranks r;
run;

/* For repeated measures using Proc Mixed, one must sort data by: 
   CROSSED FACTORS, SUBJECT, REPEATED */
/* For NON-repeated measures, sorting is not needed,
but good habit to develop for when you approach higher-order designs*/
proc sort data=vinca out=vinca; 
  by trt fert;
run;


title 'NONPARAMETRIC ANALYSIS USING PROC MIXED';
proc mixed data=vinca anovaf method=mivque0;
	class trt fert;
	model r = trt|fert / chisq;
	repeated / type=un(1) group=trt*fert; /*or could use group=group or group2*/
	lsmeans trt*fert;
	ods output lsmeans=c; *<--Output the lsmeans to dataset c, for plotting;
/*Contrasts to test the differences among trt*/
    contrast 'NT vs A' trt 1 0 0 0 0 -1;
    contrast 'NT vs B' trt 0 1 0 0 0 -1;
    contrast 'NT vs C' trt 0 0 1 0 0 -1;
    contrast 'NT vs D' trt 0 0 0 1 0 -1;
    contrast 'NT vs E' trt 0 0 0 0 1 -1;
/*Contrasts for differences between fert*/
	contrast 'fert 1 vs 2' fert 1 -1 0;
	contrast 'fert 2 vs 3' fert 0 1 -1;
run;


/*Obtain the relative treatment effects and their confidence intervals with the LD_CI macro*/
title 'TRT*FERT RELATIVE EFFECTS';
%ld_ci(data=vinca, var=dsr21, group=group2, subject=subject);
title 'TRT RELATIVE EFFECTS';
%ld_ci(data=vinca, var=dsr21, group=trt, subject=subject);
title 'FERT RELATIVE EFFECTS';
%ld_ci(data=vinca, var=dsr21, group=fert, subject=subject);



/*                 PLOTTING RELATIVE TREATMENT EFFECTS                */
/*One may want to visualize the relative treatment effects.
  Here we calculate the relative treatment effects from the lsmeans*/

/*The lsmeans from the Proc Mixed output have been saved to dataset c*/
title 'LSMEANS FROM PROC MIXED';
proc print data=c;
run;
data c2;
  set c;
  re = (Estimate-0.5)/90; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENT EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc tabulate data=c2 f=6.2;
  class trt fert;
  var re;
  table trt, fert*re*(mean); *<--Table of the relative effects;
run;


/*Now plot re*/
goptions reset=all;
symbol1 v=dot;
title 'PLOT OF RELATIVE TREATMENT EFFECTS';
proc gplot data = c2;
  plot re*trt = fert;
  plot re*fert = trt;
run;
quit;









