/*               THREE-WAY FACTORIAL                 */

/*Requires the following macros:
LD_CI
*/

/*Make sure to specify the correct pathway for your computer*/
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\LD_CI.sas';

/*BEAN RUSSET CAUSED BY PLECTOSPORIUM TABACINUM*/
/*There are two bean varieties, Brio and Goldmine
with pods inoculated at the pin, medium, or large stage.
Pods were either damaged mechanically (wounded), or undamaged before inoculation.
Disease (a russett) was rated on a 0 - 9 ordinal scale,
0= no disease,
1=a few specks with up to 2% of the pod with russet symptoms
2=2-5%
3=5-10%
4=10-25%
5=25-50%
6=50-70%
7=70-90%
8=90 to <100%
9=100% pod completely covered
*/

options ls =100 ps= 1000 nodate nonumber;
data run3;
input subject variety $ rep damage $ podsize $ rating;
group = right(right(variety)||"_"||damage)||"_"||podsize; *<--Combos of variety x damage x podsize;
group2 = right(variety)||"_"||left(podsize); *<--Will use this later;
cards;
1	Brio	1	dam	pin	3
2	Brio	2	dam	pin	3
3	Brio	3	dam	pin	3
4	Brio	1	un	pin	2
5	Brio	2	un	pin	2
6	Brio	3	un	pin	3
7	Brio	1	dam	med	3
8	Brio	2	dam	med	5
9	Brio	3	dam	med	3
10	Brio	1	un	med	4
11	Brio	2	un	med	3
12	Brio	3	un	med	4
13	Brio	1	dam	large	5
14	Brio	2	dam	large	5
15	Brio	3	dam	large	5
16	Brio	1	un	large	5
17	Brio	2	un	large	5
18	Brio	3	un	large	5
19	GoldMine	1	dam	pin	4
20	GoldMine	2	dam	pin	1
21	GoldMine	3	dam	pin	1
22	GoldMine	1	un	pin	1
23	GoldMine	2	un	pin	1
24	GoldMine	3	un	pin	1
25	GoldMine	1	dam	med	5
26	GoldMine	2	dam	med	6
27	GoldMine	3	dam	med	5
28	GoldMine	1	un	med	5
29	GoldMine	2	un	med	5
30	GoldMine	3	un	med	5
31	GoldMine	1	dam	large	5
32	GoldMine	2	dam	large	5
33	GoldMine	3	dam	large	4
34	GoldMine	1	un	large	5
35	GoldMine	2	un	large	6
36	GoldMine	3	un	large	5
run;
/*Check the data*/
title 'RAW DATA';
proc print data=run3;
run;

/*Summary of the median ratings*/
title 'MEDIAN RATINGS SUMMARY';
proc tabulate data=run3 f=6.1 order=data;
  class variety damage podsize;
  var rating;
  table variety*damage, podsize*rating*(median); *<--Request median rating;
run;


/*         NONPARAMETRIC ANALYSIS WITH PROC MIXED   */
proc sort data=run3 out=run3;
by variety podsize damage;
run;
proc rank data=run3 out=run3;
var rating;
ranks r;
run;

title 'ANALYSIS WITH PROC MIXED';
proc mixed data=run3 anovaf method=mivque0;
class variety damage podsize;
model r = variety|podsize|damage;
repeated / type=un(1) group=variety*damage*podsize;
lsmeans variety*podsize*damage;
ods output lsmeans=c; *<--Output the lsmeans to dataset c, for plotting;
contrast 'Brio pin vs. medium' podsize 0 1 -1 variety*podsize 0 1 -1  0 0 0;
contrast 'Brio pin vs. large' podsize 1 0 -1 variety*podsize 1 0 -1  0 0 0;
contrast 'Brio medium vs. large' podsize 1 -1 0 variety*podsize 1 -1 0  0 0 0;

contrast 'Goldmine pin vs. medium' podsize 0 1 -1 variety*podsize 0 0 0  0 1 -1;
contrast 'Goldmine pin vs. large' podsize 1 0 -1 variety*podsize 0 0 0  1 0 -1;
contrast 'Goldmine medium vs. large' podsize 1 -1 0 variety*podsize 0 0 0  1 -1 0;
run;

/*Confidence intervals for relative treatment effects*/
title 'RELATIVE TREATMENT EFFECTS AND THEIR CONFIDENCE INTERVALS';
%ld_ci(data=run3, var=rating, group=group, alpha=0.05, subject=subject);
run;

/*                 PLOTTING RELATIVE TREATMENT EFFECTS                */
/*One may want to visualize the relative treatment effects.
  Here we calculate the relative treatment effects from the lsmeans*/
data c2;
  set c;
  re = (Estimate-0.5)/36; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENT EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc tabulate data=c2 f=6.2;
  class variety damage;
  class podsize /descending; *<--I want the table heading to run from pin to large;
  var re;
  table variety*damage, podsize*re*(mean); *<--Table of the relative effects;
run;

/*Now plot re*/
goptions reset=all;
symbol1 v=dot;
title 'RELATIVE TREATMENT EFFECTS';
proc gplot data = c2;
  plot re*variety;
  plot re*damage;
  plot re*podsize=variety/ hreverse; *<--So that the x-axis labels run 'pin, med, large';
run;
quit;

                                    /*NEW SECTION*/
                          /*VARIETY BY PODSIZE INTERACTION*/
/*As there was no effect of damage, but the variety*podsize interaction was significant,
we may want to look at the marginal treatment effects for variety*podsize combinations*/

/*We can obtain the relative effects with the LD_CI macro*/
title 'RELATIVE TREATMENT EFFECTS FOR VARIETY x PODSIZE';
%ld_ci(data=run3, var=rating, group=group2, alpha=0.05, subject=subject);

/*Get the relative effects from Proc Mixed, output for plotting*/
title 'RE FOR VARIETY X PODSIZE WITH PROC MIXED';
proc mixed data=run3 anovaf method=mivque0;
class variety damage podsize;
model r = variety|podsize|damage;
repeated / type=un(1) group=variety*damage*podsize;
lsmeans variety*podsize;
ods output lsmeans=d; *<--Output the lsmeans to dataset d, for plotting;
run;
/*Calculate the re from the Proc Mixed lsmeans output*/
data d2;
  set d;
  re = (Estimate-0.5)/36; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;

title 'RELATIVE TREATMENT EFFECTS FOR VARIETY x PODSIZE CALCULATED FROM PROC MIXED LSMEANS';
proc tabulate data=d2 f=6.2;
  class variety;
  class podsize /descending; 
  var re;
  table variety, podsize*re*(mean); *<--Table of the relative effects;
run;

/*Now plot re*/
goptions reset=all;
symbol1 v=dot i=join;
title 'RELATIVE TREATMENT EFFECTS FOR VARIETY x PODSIZE';
proc gplot data = d2;
  plot re*podsize=variety /hreverse;
run;
quit;


