/*               SPLIT PLOT EXAMPLE      */

/*Requires the following macros:
F1_LD_F1
LD_CI
*/

/*Make sure to specify the correct pathway for your computer*/
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\F1_LD_F1.sas';
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\LD_CI.sas';

/*Data courtesy of Bob Harveson, University of Nebraska*/
/*Harveson & Rush 2002 Pl. Dis. 86:901-908*/
/*Effect of irrigation and beet variety on beet root rot*/

/*plot = plot number*/
/*irr = irrigation treatment (wet or dry)*/
/*var = variety (8 trt levels)*/
/*rep = replicate (they did 6 reps)*/
/*rating = median rating on a 0-4 scale for the plot.
  Ratings done on each beet root, but variable number of roots
  were harvested per plot*/
/*subject = subject code.  Each irr by rep combination is a unique
  subject (12 subjects altogether)*/

options ls =100 ps= 1000 nodate nonumber;
data beet;
input plot irr $ var $ subject rep rating;
sub1 = right(irr)||"_"||put(rep,1.); *<--More descriptive subject label;
cards;
1	wet	Rhizosen	1	1	2
2	wet	HH67	    1	1	3
3	wet	Ranger	    1	1	3
4	wet	MH9155	    1	1	2
5	wet	RhizRang	1	1	3
6	wet	HH67Rang	1	1	3
7	wet	Rang9155	1	1	3
8	wet	4waymix	    1	1	2
9	dry	4waymix	    2	1	1
10	dry	Rang9155	2	1	4
11	dry	HH67Rang	2	1	2
12	dry	RhizRang	2	1	1
13	dry	MH9155	2	1	2
14	dry	Ranger	2	1	2
15	dry	HH67	2	1	3
16	dry	Rhizosen	2	1	2
17	dry	Rang9155	3	2	2
18	dry	HH67	3	2	2
19	dry	4waymix	3	2	2
20	dry	Rhizosen	3	2	2
21	dry	MH9155	3	2	2
22	dry	HH67Rang	3	2	2
23	dry	Ranger	3	2	2
24	dry	RhizRang	3	2	2
25	wet	RhizRang	4	2	2
26	wet	Ranger	4	2	2
27	wet	HH67Rang	4	2	3
28	wet	MH9155	4	2	2
29	wet	Rhizosen	4	2	3
30	wet	4waymix	4	2	3
31	wet	HH67	4	2	3
32	wet	Rang9155	4	2	2
33	wet	MH9155	5	3	2
34	wet	Ranger	5	3	3
35	wet	HH67Rang	5	3	2
36	wet	RhizRang	5	3	2
37	wet	Rang9155	5	3	2
38	wet	4waymix	5	3	3
39	wet	HH67	5	3	3
40	wet	Rhizosen	5	3	2
41	dry	Rhizosen	6	3	2
42	dry	HH67	6	3	2
43	dry	4waymix	6	3	2
44	dry	Rang9155	6	3	2
45	dry	RhizRang	6	3	1
46	dry	HH67Rang	6	3	3
47	dry	Ranger	6	3	3
48	dry	MH9155	6	3	2
49	dry	Ranger	7	4	2
50	dry	Rhizosen	7	4	2
51	dry	4waymix	7	4	2
52	dry	HH67Rang	7	4	2
53	dry	MH9155	7	4	1
54	dry	RhizRang	7	4	2
55	dry	Rang9155	7	4	1
56	dry	HH67	7	4	1
57	wet	HH67	8	4	2
58	wet	Rang9155	8	4	2
59	wet	RhizRang	8	4	4
60	wet	MH9155	8	4	2
61	wet	HH67Rang	8	4	3
62	wet	4waymix	8	4	2
63	wet	Rhizosen	8	4	2
64	wet	Ranger	8	4	3
65	wet	HH67	9	5	2
66	wet	MH9155	9	5	2
67	wet	Rang9155	9	5	2
68	wet	RhizRang	9	5	3
69	wet	Rhizosen	9	5	3
70	wet	Ranger	9	5	3
71	wet	HH67Rang	9	5	3
72	wet	4waymix	9	5	2
73	dry	4waymix	10	5	2
74	dry	HH67Rang	10	5	2
75	dry	Ranger	10	5	2
76	dry	Rhizosen	10	5	2
77	dry	RhizRang	10	5	3
78	dry	Rang9155	10	5	2
79	dry	MH9155	10	5	2
80	dry	HH67	10	5	2
81	dry	Rhizosen	11	6	2
82	dry	Ranger	11	6	2
83	dry	HH67	11	6	2
84	dry	MH9155	11	6	2
85	dry	RhizRang	11	6	2
86	dry	HH67Rang	11	6	2
87	dry	4waymix	11	6	2
88	dry	Rang9155	11	6	1.5
89	wet	Rang9155	12	6	1
90	wet	4waymix	12	6	2
91	wet	HH67Rang	12	6	3
92	wet	RhizRang	12	6	3
93	wet	MH9155	12	6	2
94	wet	HH67	12	6	3
95	wet	Ranger	12	6	3
96	wet	Rhizosen	12	6	4
;
run;
title 'BEET DATASET';
proc print data=beet;
run;

/*Summary of the median ratings*/
title 'MEDIAN RATINGS SUMMARY';
proc tabulate data=beet f=8.1;
  class var irr;
  var rating;
  table irr, var*rating*(median); *<--Request median rating;
run;


/*Nonparametric analysis using the F1_LD_F1 macro*/
title 'NONPARAMETRIC ANALYSIS USING THE F1_LD_F1 MACRO';
/*NOTE: factor=whole plot variable; time=subplot variable*/
%F1_LD_F1(data=beet, factor=irr, var=rating, time=var, subject=sub1);
run;

/*Calculate the confidence intervals*/
title 'RELATIVE TREATMENT EFFECTS FROM THE LD_CI MACRO';
%LD_CI(data=beet, var=rating, group=irr, time=var, subject=sub1);



			/*        ANALYSIS USING PROC MIXED    */
title 'NONPARAMETRIC ANALYSIS USING PROC MIXED';
/*Calculate the ranks*/
proc rank data=beet out=beet;
	var rating;
    ranks r;
run;
/*Sort by subject, then sub-plot factor*/
proc sort data=beet out=beet;
  by subject var;
run;

proc mixed data=beet anovaf method=mivque0;
	class irr var sub1;
	model r = irr|var / chisq;
	repeated / sub=sub1 group=irr type=un;
	lsmeans irr*var;
	ods output lsmeans=c; *<--Output the lsmeans to dataset c;
	/*Specify contrasts of interest*/
    contrast '4waymix vs HH67 irr=wet' var 1 -1 0 0 0 0 0 0
         irr*var 0 0 0 0 0 0 0 0  1 -1 0 0 0 0 0 0;
	contrast '4waymix vs Ranger irr=wet' var 1 0 0 0 0 -1 0 0
         irr*var 0 0 0 0 0 0 0 0  1 0 0 0 0 -1 0 0;
    contrast '4waymix vs Rang9155 irr=wet' var 1 0 0 0 -1 0 0 0
	     irr*var 0 0 0 0 0 0 0 0  1 0 0 0 -1 0 0 0;
run;


title 'LSMEANS FROM PROC MIXED';
/*Calculate the relative treatment effects from the lsmeans*/
data c2;
  set c;
  re = (Estimate-0.5)/96; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENT EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc tabulate data=c2 f=6.2;
  class var irr;
  var re;
  table irr, var*re*(mean); *<--Table of the relative effects;
run;

/*Now plot re*/
title 'RELATIVE EFFECTS FOR VARIETY';
goptions reset=all;
symbol1 v=dot;
proc gplot data = c2;
  plot re*var = irr;
run;
quit;


/*               AN ALTERNATIVE METHOD OF DEALING WITH THE SPLIT PLOT ANALYSIS*/
/*In a parametric analysis of a split plot, one assumes a constant variance and covariance
structure between the subplots. This is equivalent to type=cs covariance structure. 
In the nonparametric approach, instead of using the type=un covariance structure,
one can model the covariance matrix as type=csh, i.e. a heterogenous compound-symmetry structure.
In the csh structure, there are separate variances and covariances between subplots, 
but the correlation between subplots is constant. The csh structure has fewer parameters than type=un.
  
Doesn't change interpretation here, but it easily can. 
*/
%macro skip;
title 'Alternative analysis of split plot, with single correlation between sub-plots';
proc mixed data=beet anovaf method=mivque0;
        class irr var sub1;
        model r = irr|var / chisq;
        repeated / sub=sub1 group=irr type=csh; *<--Heterogeneous compound symmetry;
        lsmeans irr*var;
        ods output lsmeans=alt; *<--Output the lsmeans to dataset alt;
        /*Specify contrasts of interest*/
    contrast '4waymix vs HH67 irr=wet' var 1 -1 0 0 0 0 0 0
         irr*var 0 0 0 0 0 0 0 0  1 -1 0 0 0 0 0 0;
        contrast '4waymix vs Ranger irr=wet' var 1 0 0 0 0 -1 0 0
         irr*var 0 0 0 0 0 0 0 0  1 0 0 0 0 -1 0 0;
    contrast '4waymix vs Rang9155 irr=wet' var 1 0 0 0 -1 0 0 0
             irr*var 0 0 0 0 0 0 0 0  1 0 0 0 -1 0 0 0;
run;
%mend;







