/*         2-WAY FACTORIAL REPEATED MEASURES        */

/*Requires the macros
F2_LD_F1
LD_CI
*/

/*Specify the pathways to the macros for your computer*/
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\LD_CI.sas';
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\F2_LD_F1.sas';

/*Data courtesy of Camilla Yandoc, USDA ARS USHRL*/
options ls =100 ps= 1000 nodate nonumber;
/*
inoc = inoculum level of P. nicotianae zoospores: 2 3 4
fert = fertilizer concentration 0=no fertilizer, 0.5x, 1.0x, 2.0x
rep = replication: 1 2 3 4 5 
dsr = disease rating 0-4 scale on day 7 14 21, where
0 = no disease
1 = lesion and/or stem constriction visible
2 = 1+ lower leaves wilting
3 = 2+ upper leaves wilting
4 = dead
pdt7, pdt14, pdt21 are variables we are not going to use
*/
/*original dataset*/
data vinca;
input inoc fert rep dsr7 pdt7 dsr14 pdt14 dsr21 pdt21;
group = "inoc="||put(inoc,1.)||"_"||"fert="||left(put(fert,3.));
sub1 = _n_; *<--Unique label for every inoc x fert x rep combination;
cards;
2	0.0	1	0	0.00	0	0.00	0	0.00
2	0.0	2	0	0.00	0	0.00	0	0.00
2	0.0	3	0	0.00	0	0.00	0	0.00
2	0.0	4	0	0.00	0	0.00	0	0.00
2	0.0	5	0	0.00	0	0.00	0	0.00
2	0.5	1	0	0.00	0	0.00	0	0.00
2	0.5	2	0	0.00	0	0.00	0	0.00
2	0.5	3	0	0.00	0	0.00	0	0.00
2	0.5	4	0	0.00	2	0.17	4	1.00
2	0.5	5	0	0.00	0	0.00	0	0.00
2	1.0	1	0	0.00	0	0.00	0	0.00
2	1.0	2	0	0.00	0	0.00	0	0.00
2	1.0	3	0	0.00	0	0.00	0	0.00
2	1.0	4	0	0.00	0	0.00	1	0.13
2	1.0	5	0	0.00	0	0.00	0	0.00
2	2.0	1	1	0.13	2	0.44	4	1.00
2	2.0	2	0	0.00	0	0.00	0	0.00
2	2.0	3	0	0.00	0	0.00	0	0.00
2	2.0	4	2	0.53	4	1.00	4	1.00
2	2.0	5	0	0.00	0	0.00	0	0.00
3	0.0	1	3	0.64	4	1.00	4	1.00
3	0.0	2	0	0.00	0	0	0	0
3	0.0	3	0	0.00	0	0	0	0
3	0.0	4	0	0.00	0	0	0	0
3	0.0	5	0	0.00	0	0	0	0
3	0.5	1	0	0.00	0	0	0	0
3	0.5	2	0	0.00	0	0	0	0
3	0.5	3	0	0.00	0	0	0	0
3	0.5	4	0	0.00	0	0	0	0
3	0.5	5	0	0.00	0	0	0	0
3	1.0	1	0	0.00	0	0	0	0
3	1.0	2	0	0.00	0	0	0	0
3	1.0	3	0	0.00	0	0	0	0
3	1.0	4	0	0.00	0	0	0	0
3	1.0	5	0	0.00	0	0	0	0
3	2.0	1	0	0.00	2	0.19	4	1.00
3	2.0	2	2	0.62	4	1.00	4	1.00
3	2.0	3	0	0.00	3	0.69	4	1.00
3	2.0	4	0	0.00	1	0.30	4	1.00
3	2.0	5	2	0.00	3	0.64	4	1.00
4	0.0	1	0	0.00	0	0	0	0
4	0.0	2	0	0.00	0	0	0	0
4	0.0	3	0	0.00	0	0	0	0
4	0.0	4	0	0.00	0	0	0	0
4	0.0	5	0	0.00	0	0	0	0
4	0.5	1	0	0.00	0	0	0	0
4	0.5	2	1	0.43	0	0	0	0
4	0.5	3	0	0.00	0	0	4	1.00
4	0.5	4	0	0.00	0	0	0	0
4	0.5	5	0	0.00	0	0	0	0
4	1.0	1	2	0.70	4	1.00	4	1.00
4	1.0	2	0	0.00	0	0	0	0
4	1.0	3	0	0.00	0	0	0	0
4	1.0	4	0	0.00	0	0	2	0.41
4	1.0	5	2	0.44	4	1.00	4	1.00
4	2.0	1	0	0.00	0	0	0	0
4	2.0	2	2	0.93	4	1.00	4	1.00
4	2.0	3	0	0.00	0	0	3	0.78
4	2.0	4	2	0.17	3	0.67	4	1.00
4	2.0	5	0	0.00	0	0	0	0
;
run;
/*Check the dataset*/
title 'ORIGINAL DATA';
* %macro skip;
proc print data=vinca;
run;
* %mend skip;

/*First, get the data in univariate format for analysis by macros and Proc Mixed*/
data vinca2;
  set vinca;
  drop pdt7 pdt14 pdt21; *<--Don't need these variables;
  t1=dsr7;
  t2=dsr14;
  t3=dsr21;
  array t{3} t1-t3; *<--Create an array;
  do i=1 to 3;
    if i=1 then time=7;
	if i=2 then time=14;
	if i=3 then time=21;
	dsr=t{i};      *<--dsr is the variable storing the rating values;
	output;
  end;
  drop i t1-t3 dsr7 dsr14 dsr21; *<--No longer needed;
run;
/*Take a look at the data in univariate format*/
%macro skip;
title 'DATA IN UNIVARIATE FORMAT';
proc print data=vinca2 noobs;
run;
%mend skip;

/*Summary of the median ratings*/
title 'MEDIAN RATINGS SUMMARY';
proc tabulate data=vinca2 f=6.1;
  class inoc fert time;
  var dsr;
  table inoc*fert, time*dsr*(median); *<--Request median rating;
run;

title 'NONPARAMETRIC ANALYSIS WITH THE F2_LD_F1 MACRO';
%F2_LD_F1(data=vinca2, var=dsr, factor1=inoc, factor2=fert, time=time, subject=sub1);
title 'RELATIVE TREATMENT EFFECTS';
%ld_ci(data=vinca2, var=dsr, group=group, time=time, subject=sub1);
title 'MARGINAL EFFECTS FOR INOC';
%ld_ci(data=vinca2, var=dsr, group=inoc, time=time, subject=sub1);
title 'MARGINAL EFFECTS FOR FERT';
%ld_ci(data=vinca2, var=dsr, group=fert, time=time, subject=sub1);


/*           NONPARAMETRIC ANALYSIS USING PROC MIXED        */
title 'ANALYSIS USING PROC MIXED';
/*First, obtain the ranks*/
proc rank data=vinca2 out=vinca2;
var dsr;
ranks r;
run;
/*Sort by main factors, then time factor*/
proc sort data=vinca2 out=vinca2;
by sub1 time;
run;
proc mixed data=vinca2 anovaf method=mivque0;
class inoc fert time sub1;
model r = inoc|fert|time /chisq;
repeated time/ type=un sub=sub1 group=inoc*fert; *<--or group=group, same definition;
lsmeans fert*time;
ods output lsmeans=c; *<--Output the lsmeans to dataset c;
/*Contrasts of possible interest*/
contrast 'fert 1 vs 2 at time=21' fert 0 0 1 -1 fert*time 0 0 0  0 0 0  0 0 1  0 0 -1;
contrast 'fert 0.5 vs 1 at time=21' fert 0 1 -1 0 fert*time 0 0 0  0 0 1  0 0 -1  0 0 0;
/*Contrasts examining the linear trends over time*/
contrast 'fert 0.5 vs 2 linear trend' fert*time 0 0 0  -1 0 1  0 0 0  1 0 -1; 
contrast 'fert 0.5 vs 1 linear trend' fert*time 0 0 0  -1 0 1  1 0 -1  0 0 0;
run;

/*                 PLOTTING RELATIVE TREATMENT EFFECTS                */
/*One may want to visualize the relative treatment effects.
  Here we calculate the relative treatment effects from the lsmeans.
  As the inoc effect was not significant, we'll look at the fert relative
  effects over time*/
data c2;
  set c;
  re = (Estimate-0.5)/180; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENT EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc tabulate data=c2 f=8.2;
  class fert time;
  var re;
  table fert, time*re*(mean); *<--Table of the relative effects;
run;

/*Now plot re*/
goptions reset=all;
symbol1 v=dot i=join;
title 'PLOT OF RELATIVE TREATMENT EFFECTS';
proc gplot data = c2;
  plot re*time = fert;
run;
quit;











