/* SM_NPana.sas */

/*	See: Shah & Madden. 2004. Phytopathology, vol. 94, pp. 33-43, and
	their electronic appendix, for details. */

/* ONE WAY LAYOUT */
/*
Nonparametric (relative marginal effects) analysis for data 
from Test 1 of Omer et al. (2000). Am. J. Pot. Res. 77: 325-333.
Assumes Version 8 or higher of SAS/STAT.
Assumes that the macros F1_LD_F1 and LD_CI are in the designated path.
NOTE: Change the pathway to these macros for your computer!
The macros are available for download at:
http://www.ams.med.uni-goettingen.de/Projekte/LD/Makros_LD.hmtl
or
http://www.ams.med.uni-goettingen.de/de/sof/ld/makros.html

*/

/* Identify pathway to macros.*/

%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\ld_ci.sas';
%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\f1_ld_f1.sas';

options ls =100 ps= 1000 nodate nocenter nonumber;

/*
isol = isolate of Verticillium dahliae
vcg = vegetative compatibility group
rep = replicate
disi = disease rating in week i (i= 1 to 6)
auc = area under disease progress curve.  Original paper analyzed this
      variable. Not used here.
sub = subject (a unique identifier for each experimental unit)
*/

data omer;
	input isol $ vcg $ rep dis1 dis2 dis3 dis4 dis5 dis6 
          auc sub;
	datalines;
83	4A	1	1	2	5	6	6	6	157.5	49
83	4A	2	1	1	4	6	6	6	143.5	50
83	4A	3	1	1	3	6	6	6	136.5	51
83	4A	4	1	1	3	6	6	6	136.5	52
83	4A	5	1	2	5	6	6	6	157.5	53
83	4A	6	1	1	3	6	6	6	136.5	54
83	4A	7	1	2	4	6	6	6	150.5	55
83	4A	8	1	2	3	6	6	6	143.5	56
111	4A	1	1	2	3	5	6	6	136.5	57
111	4A	2	1	1	2	3	6	6	108.5	58
111	4A	3	1	2	3	5	6	6	136.5	59
111	4A	4	1	1	2	4	6	6	115.5	60
111	4A	5	1	1	2	4	6	6	115.5	61
111	4A	6	1	2	2	4	6	6	122.5	62
111	4A	7	1	2	2	2	3	6	87.5	63
111	4A	8	1	1	2	5	6	6	122.5	64
120	4A	1	1	2	2	5	6	6	129.5	65
120	4A	2	1	1	1	3	4	6	87.5	66
120	4A	3	1	1	3	4	6	6	122.5	67
120	4A	4	1	1	3	5	6	6	129.5	68
120	4A	5	1	1	1	4	4	6	94.5	69
120	4A	6	1	1	2	5	6	6	122.5	70
120	4A	7	1	1	1	3	5	6	94.5	71
120	4A	8	1	1	2	3	4	6	94.5	72
201	4B	1	1	1	2	3	3	4	80.5	185
201	4B	2	1	1	1	4	4	4	87.5	186
201	4B	3	1	1	1	3	5	5	91.0	187
201	4B	4	1	2	3	4	4	4	108.5	188
201	4B	5	1	1	2	4	4	5	98.0	189
201	4B	6	1	1	1	3	3	4	73.5	190
201	4B	7	1	1	1	4	4	4	87.5	191
201	4B	8	1	1	2	3	4	5	91.0	192
202	4B	1	1	1	1	1	2	3	49.0	193
202	4B	2	1	1	1	1	1	2	38.5	194
202	4B	3	1	1	1	2	2	2	52.5	195
202	4B	4	1	1	2	2	3	3	70.0	196
202	4B	5	1	2	2	2	2	2	66.5	197
202	4B	6	1	1	1	2	3	4	66.5	198
202	4B	7	1	1	1	1	3	3	56.0	199
202	4B	8	1	1	1	3	4	4	80.5	200
203	4B	1	1	1	3	4	5	5	112.0	201
203	4B	2	1	1	1	3	4	4	80.5	202
203	4B	3	1	1	3	4	4	4	101.5	203
203	4B	4	1	1	2	4	4	5	98.0	204
203	4B	5	1	1	2	4	5	5	105.0	205
203	4B	6	1	1	2	4	5	5	105.0	206
203	4B	7	1	2	2	3	4	4	94.5	207
203	4B	8	1	2	2	3	3	4	87.5	208
;
run;

/*Check the dataset*/
proc print data=omer;
run;

/* A 1-way analysis for ratings made during week 3. */
/*Before using Proc Mixed, one needs the ranks of the observations*/
proc rank data=omer out=omer;
  var dis3; *requests ranks for the ratings made during the third week; 
  ranks r; *ranks are stored under the variable r;
run;

/*One-way analysis with Proc Mixed. Output may look different in version 9.1*/
/* The ANOVAF option is _production_ in 9.2 */
proc mixed data=omer anovaf;
	title1 '1-way analysis using MIXED, with contrasts of 4A & 4B';
	class isol;
	model r = isol / chisq ;
	repeated / type=un(1) group=isol;
	lsmeans isol /pdiff;
	contrast 'VCG4A vs VCG4B' isol 1 1 -1 -1 -1 1;
	run;

title1 '1-way analysis using macro; each observation is a subject';
%ld_ci(data=omer,var=dis3,group=isol,alpha=0.05,subject=sub); 
run;

/*-------------------------------------------------------------*/

/* REPEATED MEASURES (one whole plot, one time factor) */

/* Repeated measures analysis (disease rating over time). 
For this analysis, one must first create a SAS dataset with
a separate record for each time. */
data potato;
  set omer;
  array dis{6} dis1-dis6; *store the weekly ratings in an array;
	do i=1 to 6;
	  week = i;
	  rating=dis{i};
	  output;
	end;
	drop i dis1-dis6 auc r;
run;

/*Create a data set for testing specific time profile interactions*/
data interaction_pattern;
  input week weight1 weight2;
  datalines;
  1 1 1
  2 2 1
  3 3 2
  4 4 3
  5 5 2
  6 6 1
;
run;

title1'Potato early decay. Repeated measures analysis';
title2'Analysis using the F1_LD_F1 macro';
%F1_LD_F1(data=potato, factor=isol, var=rating, time=week, subject=sub,
          data_pit=interaction_pattern, var_pit=weight1, time_pit=week);
run;

/*Calculate the confidence intervals*/
%LD_CI(data=potato, var=rating, group=isol, time=week, subject=sub);


/*Here is the repeated measures analysis using Proc Mixed*/
/*There is sometimes an apparent 'error' in the ATS Den df (and hence P value) 
given by Proc Mixed for the test of the whole plot factor
when there is a small number of reps, so one should check
the output carefully.  There is however a workaround for this 'error'
(contact the authors for the SAS code).
In reality, this is not really an error, but is a natural consequence of
how the procedure calculates the covariance matrix, relative to how
the macros calculate the matrix -- see more detailed comments below.

Below is the Proc Mixed code (results are correct for the 
number of reps in this case)*/

/*First, obtain the ranks of the disease ratings.*/
proc rank data=potato out=potato;
  var rating;
  ranks r;
run;
/*Note that for Proc Mixed the data must be sorted by the whole-plot factor,
then by subjects, then by the sub-plot factor*/
proc sort data=potato out=potato;
  by isol sub week;
run;

/*Now the ranks are analyzed*/
title2 'Analysis with Proc Mixed, disease ratings over time';
proc mixed data=potato anovaf method=mivque0;
  class isol week;
  model r = isol|week / chisq;
  repeated week / sub=sub group=isol type=un;
  ods output tests3=s3; /* makes output file s3 with test results */
run;


/*
Note that there are two possible corrections needed
in doing the analysis with Proc Mixed (for versions 9.0 and earlier). 
First, the P values 
for the tests of the time factor and the interaction
with time need to be corrected (the denominator df should be infinity; 
we use a very large denominator df as an approximation in the code below.

The second issue is that sometimes, if the number of replications
is small, Proc Mixed may give what appears to be a wrong denomiator df for the 
main effect factor.  One needs to check the output carefully for this 'error'.
Generally, denominator df = 1 when there is a problem.
Below, we provide the code for automatically flagging this apparent 'error'
should it occur. In reality, an apparent 'error' is really due to the
way that MIXED estimates the covariance matrix. It uses a ridging method to
achieve more stable results (when matrix inverses are needed). This is 
relevant here when there are groups with zero variance or when certain 
covariances are zero. The Brunner macros do not use a ridge method. Thus,
because the covariance matrix estimate _can_ differ, the df calculations
can also differ. There is actually no right or wrong approach among these
two -- it is more of a philosophical difference.

Note: in version 9.1, corrections or adjustments may not be needed. Plus, the 
WTS and ATS results are displayed differently. 

*/

/* 
The test results are put in a file; then the correct P values are
obtained by using chi-square probabilities (=F with DDF=infinity).
Print out WTS and ATS (with flag).
*/
title3 'Corrections to Proc Mixed tests';
data s3;
	set s3;
	if (Effect ne "isol") then do;

		pval= 1 - probchi(ANOVAnumDF*ANOVAFValue,ANOVAnumDF);
		ANOVAdenDF=10000; /* ~infinity */
		end;
	if (Effect eq "isol") then do;
		pval=ANOVAProbF;
		if(ANOVADenDF <= 1 or ANOVADenDF > DenDF) then pval=-1;
		end;
	/* flag incorrect with a minus one for P */

	if (pval >= 0) then flag = 'Results OK';
	if (pval < 0) then flag = 're-run whole-plot with type=CS';
/* re-run with type=CS to get correct whole-plot result
	if df=1; otherwise, all is OK for this factor.   */

proc print data=s3;
	var Effect NumDf ChiSq ProbChiSq ANOVANumDF ANOVADenDF ANOVAFValue  pval flag;
run;

/*---------------------------------------------------------*/

/* TWO-WAY LAYOUT (2 crossed factors) */

/*
Nonparametric (relative marginal effects) analysis for data 
from Krause et al.(2001). Phytopathology 91: 1116-1123.
Assumes Version 8 or higher of SAS/STAT.
Assumes that the macro LD_CI is in the designated path.
NOTE: Change the pathway to these macros for your computer!
The macros are available for download at:
http://www.ams.med.uni-goettingen.de/Projekte/LD/Makros_LD.html
or
http://www.ams.med.uni-goettingen.de/de/sof/ld/makros.html

*/

/* Identify pathway to macros.*/

%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\ld_ci.sas';
%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\f1_ld_f1.sas';


/* batch = rep																*/
/* bioadd = biocontrol added (1=natural 2=fortified) (Factor)										*/
/* potting = potting mix (or soil media), and how it was handled (Factor)	*/
/* dismd = disease rating based on medians of subsamples					*/
/* treatment = interaction of potting and biocontrol						*/
/* subject = unique code for each record									*/

data krause;
	input batch bioadd potting dismd @@;
	treatment=10*bioadd + potting; 
    subject=100*batch + treatment;
datalines;
 1 1 1 1.00  1 2 1 1.00 
 2 1 1 1.06  2 2 1 1.06 
 3 1 1 1.06  3 2 1 1.19 
 4 1 1 1.38  4 2 1 1.06 
 5 1 1 1.19  5 2 1 1.19 
 6 1 1 1.31  6 2 1 1.13 
 7 1 1 1.25  7 2 1 1.31 
 8 1 1 1.13  8 2 1 1.25 
 1 1 2 3.88  1 2 2 2.84 
 2 1 2 4.30  2 2 2 3.52 
 3 1 2 3.20  3 2 2 2.64 
 4 1 2 3.78  4 2 2 2.94 
 5 1 2 3.34  5 2 2 2.48 
 6 1 2 3.80  6 2 2 3.73 
 7 1 2 3.30  7 2 2 4.06 
 8 1 2 2.83  8 2 2 3.41 
 1 1 3 3.14  1 2 3 1.63 
 2 1 3 2.69  2 2 3 2.23 
 3 1 3 4.39  3 2 3 2.81 
 4 1 3 3.89  4 2 3 2.44 
 5 1 3 4.17  5 2 3 1.86 
 6 1 3 2.50  6 2 3 2.44 
 7 1 3 4.00  7 2 3 2.36 
 8 1 3 2.42  8 2 3 1.98 
 1 1 4 1.13  1 2 4 1.13 
 2 1 4 1.13  2 2 4 1.44 
 3 1 4 1.50  3 2 4 1.06 
 4 1 4 1.06  4 2 4 1.06 
 5 1 4 1.06  5 2 4 1.19 
 6 1 4 1.06  6 2 4 1.81 
 7 1 4 1.44  7 2 4 1.44 
 8 1 4 1.19  8 2 4 1.38 
 1 1 5 4.06  1 2 5 3.34 
 2 1 5 3.23  2 2 5 2.98 
 3 1 5 4.38  3 2 5 4.27 
 4 1 5 2.20  4 2 5 4.09 
 5 1 5 4.02  5 2 5 4.56 
 6 1 5 3.42  6 2 5 4.25 
 7 1 5 4.14  7 2 5 3.78 
 8 1 5 4.61  8 2 5 4.50 
 1 1 6 3.86  1 2 6 3.91 
 2 1 6 4.11  2 2 6 4.56 
 3 1 6 4.27  3 2 6 2.52 
 4 1 6 3.58  4 2 6 3.08 
 5 1 6 3.44  5 2 6 4.14 
 6 1 6 3.14  6 2 6 3.67 
 7 1 6 3.33  7 2 6 3.80 
 8 1 6 4.33  8 2 6 3.92 
 1 1 7 1.44  1 2 7 1.06 
 2 1 7 1.44  2 2 7 1.13 
 3 1 7 1.31  3 2 7 1.44 
 4 1 7 1.06  4 2 7 1.19 
 5 1 7 1.19  5 2 7 1.00 
 6 1 7 1.06  6 2 7 2.31 
 7 1 7 1.00  7 2 7 1.38 
 8 1 7 1.25  8 2 7 1.13 
 1 1 8 3.72  1 2 8 3.23 
 2 1 8 3.88  2 2 8 3.25 
 3 1 8 3.28  3 2 8 4.53 
 4 1 8 3.97  4 2 8 4.63 
 5 1 8 3.55  5 2 8 2.95 
 6 1 8 2.98  6 2 8 4.50 
 7 1 8 3.91  7 2 8 4.05 
 8 1 8 4.17  8 2 8 3.56 
 1 1 9 2.94  1 2 9 2.75 
 2 1 9 3.94  2 2 9 2.53 
 3 1 9 4.17  3 2 9 2.77 
 4 1 9 3.92  4 2 9 3.19 
 5 1 9 4.09  5 2 9 2.27 
 6 1 9 3.72  6 2 9 4.11 
 7 1 9 3.89  7 2 9 3.31 
 8 1 9 4.09  8 2 9 3.91 
;
run;

title 'Analysis of Krause et al. data set';
title2 'Marginal effects model by Proc Mixed';

proc print data=krause;
run;

/*First, obtain the ranks*/
proc rank data=krause out=krause;
  var dismd; 
  ranks r;
run;

/* For repeated measures using Proc Mixed, one must sort data by: 
   CROSSED FACTORS, SUBJECT, REPEATED */
/* For NON-repeated measures, sorting is not needed */
proc sort data=krause out=krause; 
  by bioadd potting;
run;

/* Note that the analysis is done on the RANKS (obtained from Proc Rank). 
The ANOVAF gives the Anova-Type Statistic (ATS), but is not yet a
documented SAS option (i.e.not in manuals)
For repeated measures, must use MIVQUE0 method; for factorials, not required.
Must use CHISQ option for Wald-Type Statistics (WTSs)
Must use REPEATED, with GROUP = A*B*C (or whatever), and unstructured/diagonal
residual variances [type=UN(1)]
Note: p_i,j = (1/N)*(Rbar_i,j - 0.5) ; Rbar_i,j is given as LSMEANS   */

proc mixed data=krause anovaf /* method=mivque0 */;
	class bioadd potting;
	model r = bioadd|potting / chisq;
	repeated / type=un(1) group=bioadd*potting;
	lsmeans bioadd|potting;
run;


/* Now get confidence intervals and variances for p_i,j values (marginal effects)  */
/* There can be only one factor for this CI macro. So, use Treatment (interaction) */

title2 'confidence intervals';
%LD_CI(data=krause,var=dismd,group=treatment,alpha=0.05,subject=subject);

run;

/*-------------------------------------------------------------*/

/* REPEATED MEASURES (one whole plot, one time factor) */

/*
Nonparametric (relative marginal effects) analysis of 
wheat powdery mildew in a variety  trial, 1995.
Lipps & Madden (unpublished data).
Assumes Version 8 or higher of SAS/STAT.
Assumes that the macros F1_LD_F1 and LD_CI are in the designated path.
NOTE: Change the pathway to these macros for your computer!
The macros are available for download at:
http://www.ams.med.uni-goettingen.de/Projekte/LD/Makros_LD.hmtl
or
http://www.ams.med.uni-goettingen.de/de/sof/ld/makros.html

*/

/* Identify pathway to macros.*/

%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\ld_ci.sas';
%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\f1_ld_f1.sas';


/*
Three varieties: 1) Becker; 6) Cardinal; 7) Dynasty.
Five assessment times: 	1) day 130 (GS 8)
						2) day 139 (GS 9)
						3) day 143 (GS 10)
						4) day 150 (GS 10.3)
						5) day 156 (GS 10.5.1).
Four replications, giving 3*4 = 12 unique subjects.

Response (y): 0-10 rating score (based on % severity
and highest leaf with symptoms).

 cultivar = wheat cultivar
 time = assessment time (growth stage)
 dis = rating score
 sub = subject*/

 
data wheat;
	input cultivar time dis sub;
datalines;
1	1	2.0	11
1	1	0.0	21
1	1	3.0	31
1	1	2.0	41
1	2	3.5	11
1	2	2.5	21
1	2	5.0	31
1	2	3.0	41
1	3	2.0	11
1	3	5.0	21
1	3	6.0	31
1	3	5.0	41
1	4	8.0	11
1	4	7.0	21
1	4	8.0	31
1	4	8.0	41
1	5	8.5	11
1	5	8.0	21
1	5	10.0 31
1	5	9.0	41
6	1	2.0	16
6	1	2.0	26
6	1	2.0	36
6	1	0.0	46
6	2	2.0	16
6	2	2.0	26
6	2	4.0	36
6	2	2.0	46
6	3	3.0	16
6	3	5.0	26
6	3	5.5	36
6	3	5.5	46
6	4	5.0	16
6	4	5.0	26
6	4	6.0	36
6	4	6.0	46
6	5	5.0	16
6	5	8.0	26
6	5	7.5	36
6	5	7.0	46
7	1	0.0	17
7	1	2.0	27
7	1	2.5	37
7	1	0.0	47
7	2	0.0	17
7	2	2.0	27
7	2	2.0	37
7	2	5.0	47
7	3	1.0	17
7	3	2.0	27
7	3	5.0	37
7	3	5.0	47
7	4	2.5	17
7	4	5.0	27
7	4	5.0	37
7	4	4.0	47
7	5	5.0	17
7	5	6.5	27
7	5	6.5	37
7	5	5.0	47
;
run;

title1 'wheat powdery mildew, 1995; 3 cultivars, 5 times';
/* see annotated output (lipps.doc) for explanations */
%f1_ld_f1(data=wheat,var=dis,factor=cultivar,time=time,subject=sub);
run;
%ld_ci(data=wheat,var=dis,group=cultivar,time=time,alpha=0.05,subject=sub);
run;

/*----------------------------------------------------------*/

/* SPLIT PLOT */

/*
Nonparametric (relative marginal effects) analysis of 
beet root decay. Data are from Harveson & Rush 2002 Pl. Dis. 86:901-908.
Assumes Version 8 or higher of SAS/STAT.
Assumes that the macros F1_LD_F1 and LD_CI are in the designated path.
NOTE: Change the pathway to these macros for your computer!
The macros are available for download at:
http://www.ams.med.uni-goettingen.de/Projekte/LD/Makros_LD.hmtl
or
http://www.ams.med.uni-goettingen.de/de/sof/ld/makros.html

*/

/* Identify pathway to macros.*/

%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\ld_ci.sas';
%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\f1_ld_f1.sas';

/*Effect of irrigation and beet variety on beet root rot*/
/*Disease ratings done on a 0-4 scale*/
/*Data here are for planting 2*/

/*plot = plot number*/
/*irr = irrigation treatment (wet or dry)*/
/*var = variety (8 trt levels)*/
/*rep = replicate (they did 6 reps)*/
/*rating = median rating on the 0-5 scale for the plot.
  Ratings done on each beet root, but variable number of roots
  were harvested per plot*/
/*subject = subject code.  Each irr by rep combination is a unique
  subject (12 subjects altogether)*/

options ls =100 ps= 1000 nodate nocenter nonumber;
data beet;
input plot irr $ var $ subject rep rating;
cards;
1	wet	Rhizosen	1	1	2
2	wet	HH67	1	1	3
3	wet	Ranger	1	1	3
4	wet	MH9155	1	1	2
5	wet	RhizRang	1	1	3
6	wet	HH67Rang	1	1	3
7	wet	Rang9155	1	1	3
8	wet	4waymix	1	1	2
9	dry	4waymix	2	1	1
10	dry	Rang9155	2	1	4
11	dry	HH67Rang	2	1	2
12	dry	RhizRang	2	1	1
13	dry	MH9155	2	1	2
14	dry	Ranger	2	1	2
15	dry	HH67	2	1	3
16	dry	Rhizosen	2	1	2
17	dry	Rang9155	3	2	2
18	dry	HH67	3	2	2
19	dry	4waymix	3	2	2
20	dry	Rhizosen	3	2	2
21	dry	MH9155	3	2	2
22	dry	HH67Rang	3	2	2
23	dry	Ranger	3	2	2
24	dry	RhizRang	3	2	2
25	wet	RhizRang	4	2	2
26	wet	Ranger	4	2	2
27	wet	HH67Rang	4	2	3
28	wet	MH9155	4	2	2
29	wet	Rhizosen	4	2	3
30	wet	4waymix	4	2	3
31	wet	HH67	4	2	3
32	wet	Rang9155	4	2	2
33	wet	MH9155	5	3	2
34	wet	Ranger	5	3	3
35	wet	HH67Rang	5	3	2
36	wet	RhizRang	5	3	2
37	wet	Rang9155	5	3	2
38	wet	4waymix	5	3	3
39	wet	HH67	5	3	3
40	wet	Rhizosen	5	3	2
41	dry	Rhizosen	6	3	2
42	dry	HH67	6	3	2
43	dry	4waymix	6	3	2
44	dry	Rang9155	6	3	2
45	dry	RhizRang	6	3	1
46	dry	HH67Rang	6	3	3
47	dry	Ranger	6	3	3
48	dry	MH9155	6	3	2
49	dry	Ranger	7	4	2
50	dry	Rhizosen	7	4	2
51	dry	4waymix	7	4	2
52	dry	HH67Rang	7	4	2
53	dry	MH9155	7	4	1
54	dry	RhizRang	7	4	2
55	dry	Rang9155	7	4	1
56	dry	HH67	7	4	1
57	wet	HH67	8	4	2
58	wet	Rang9155	8	4	2
59	wet	RhizRang	8	4	4
60	wet	MH9155	8	4	2
61	wet	HH67Rang	8	4	3
62	wet	4waymix	8	4	2
63	wet	Rhizosen	8	4	2
64	wet	Ranger	8	4	3
65	wet	HH67	9	5	2
66	wet	MH9155	9	5	2
67	wet	Rang9155	9	5	2
68	wet	RhizRang	9	5	3
69	wet	Rhizosen	9	5	3
70	wet	Ranger	9	5	3
71	wet	HH67Rang	9	5	3
72	wet	4waymix	9	5	2
73	dry	4waymix	10	5	2
74	dry	HH67Rang	10	5	2
75	dry	Ranger	10	5	2
76	dry	Rhizosen	10	5	2
77	dry	RhizRang	10	5	3
78	dry	Rang9155	10	5	2
79	dry	MH9155	10	5	2
80	dry	HH67	10	5	2
81	dry	Rhizosen	11	6	2
82	dry	Ranger	11	6	2
83	dry	HH67	11	6	2
84	dry	MH9155	11	6	2
85	dry	RhizRang	11	6	2
86	dry	HH67Rang	11	6	2
87	dry	4waymix	11	6	2
88	dry	Rang9155	11	6	1.5
89	wet	Rang9155	12	6	1
90	wet	4waymix	12	6	2
91	wet	HH67Rang	12	6	3
92	wet	RhizRang	12	6	3
93	wet	MH9155	12	6	2
94	wet	HH67	12	6	3
95	wet	Ranger	12	6	3
96	wet	Rhizosen	12	6	4
;
run;

/*Analysis using the F1_LD_F1 macro*/
title1'Effect of irrigation and variety on beet root decay';
title2'Analysis using the F1_LD_F1 macro';
%F1_LD_F1(data=beet, factor=irr, var=rating, time=var, subject=subject);
run;

/*Calculate the confidence intervals*/
title2'Confidence intervals using the LD_CI macro';
%LD_CI(data=beet, var=rating, group=irr, time=var, subject=subject);

run;




/*
Nonparametric (relative marginal effects) analysis for data 
generated based on a log-normal distribtuion.

Demonstration of how to use MIXED to get an exact Kruskal-Wallis result.
Also demonstrates how to do multiple comparisons.

Assumes Version 8 or higher of SAS/STAT.
Assumes that the macros F1_LD_F1, OWL, and LD_CI are in the designated path.
NOTE: Change the pathway to these macros for your computer!
The macros are available for download at:
http://www.ams.med.uni-goettingen.de/de/sof/ld/makros.html
*/

options linesize=100 pagesize=54;

/* Identify pathway to macros.*/

%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\ld_ci.sas';
%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\f1_ld_f1.sas';
%INCLUDE 'c:\Documents and Settings\madden.1\My Documents\My SAS Files\owl.sas';

/*
x = response variable
trt = grouping variable
sub = subject (a unique identifier for each experimental unit)
*/

data a;
	input x trt sub;
	datalines;
2.3331	1	1
2.5055	1	2
10.3720	1	3
14.2850	1	4
3.3115	1	5
14.0891	1	6
4.9397	1	7
26.6215	1	8
12.0446	2	9
1.0532	2	10
2.3361	2	11
0.9942	2	12
23.4494	2	13
45.2273	2	14
32.5924	2	15
1.8496	2	16
4.3041	3	17
3.1028	3	18
1.7706	3	19
2.8234	3	20
0.6127	3	21
0.7124	3	22
3.4296	3	23
1.1349	3	24
0.4564	4	25
7.6816	4	26
75.8015	4	27
6.9298	4	28
0.0643	4	29
0.5749	4	30
0.8770	4	31
0.7885	4	32
59.2746	5	33
44.6181	5	34
45.2938	5	35
38.6319	5	36
69.4950	5	37
29.3468	5	38
38.8895	5	39
32.4833	5	40
51.6112	6	41
31.4588	6	42
0.4729	6	43
4.3584	6	44
1.7856	6	45
18.4319	6	46
13.9582	6	47
26.0286	6	48

;

run;


/*Before using Proc Mixed, one needs the ranks of the observations*/
proc rank data=a out=a;
  var x; *requests ranks for the ratings ; 
  ranks r; *ranks are stored under the variable r;
run;

/*One-way analysis with Proc Mixed; full marginal treatment effects analysis*/
proc mixed data=a anovaf;
	title1 '1-way analysis using MIXED, with contrasts of two groups';
	title2 'Full marginal-treatment-effects analysis of Brunner';
	class trt;
	model r = trt / chisq ;
	repeated / type=un(1) group=trt;
	lsmeans trt /pdiff;
	contrast 'A vs B' trt 1 1 -1 -1 -1 1;
	run;

title1 'Estimated marginal treatment effects using macro; each observation is a subject';
title2 '';

%ld_ci(data=a,var=x,group=trt,alpha=0.05,subject=sub); 
run;

title1 'Direct 1-way Kruskal-Wallis analysis with macro';
title2 'But, variances of relative treatment effects direct from data (not assumed)';
%owl(data=a,var=x,group=trt);

run;

title1 'Direct 1-way Kruskal-Wallis analysis with SAS nonparametric PROCedure';
title2 '';
proc npar1way data=a wilcoxon;
	class trt;
	var x;
run;

/* Get Kruskal-Wallis with MIXED. Must force the single (residual) variance to
equal N*(N+1)/12 = 48*49/12 = 196 here.   */

proc mixed data=a noprofile; *prevent estimation of any variance parameters;
	title1 'Kruskal Wallis approach with MIXED; Chi-square = WTS = KW statistic here';
	title2 'Need NOPROFILE and fixed error variance, N*(N+1)/12, with PARMS (196)/eqcons=1 ';
	title3 'No tie correction. St.errors of R_bar and differences are KW type (here)';
	class trt;
	model r = trt / chisq; *chisquare statistic is KW statistic (no tie correction);
	parms (196) / eqcons=1; *forces error variance to be fixed ;
	lsmeans trt / pdiff df =1000; *high df so that normal (not t) distribution is used;
	*could insert ADJUST=BON after / for Dunn procedure (type I error protection);

run;
	title2 '';
	title3 '';
	title1 '';
run;




